@@ -11,9 +11,9 @@ from rb.core.word import Word
 class Span(TextElement):
 
 
-    def __init__(self, lang: Lang, text: str, words: List[Word],
+    def __init__(self, lang: Lang, text: str, words: List[Word], index_in_container: int,
          depth: int = TextElementType.SPAN.value):
-        super().__init__(lang, text, depth, container=words[0].container)
+        super().__init__(lang, text, index_in_container, depth, container=words[0].container)
         self.components = words
 
     def get_root(self) -> Word:
@@ -27,4 +27,4 @@ class Span(TextElement):
     def from_spacy_span(cls, lang: Lang, spacy_span: spacy.tokens.Span, words: Dict[int, Word]) -> "Word":
         text = spacy_span.text
         our_words = [words[i] for i in range(spacy_span.start, spacy_span.end)]
-        return Span(lang=lang, text=text, words=our_words)
+        return Span(lang=lang, text=text, words=our_words, index_in_container=our_words[0].index_in_container)
